"""
    Matreex

    This file is part of Matreex.

    Matreex is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Matreex is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Matreex. If not, see <http://www.gnu.org/licenses/>.
"""
import os
from .matreex import run_matreex_oma, run_matreex_panther

def run_matreex(args):
    """
    - src (oma, panther, json)
    - ids (HOG1,HOG2)
    - out (out_path + name)
    - root_taxon
    """
    ids = args.ids.split(',')
    out_path, name = os.path.split(args.out)
    if not out_path: out_path = './'
    if args.src == 'oma':
        run_matreex_oma(
            ids, out_path, taxon2description={}, taxon2branch_color={}, taxon2matrix_color={}, ref_taxon=args.root_taxon,
            ref_sp='', id2gene_name={}, fasta_fn=None, name=name, max_gene_nr=1000000, exp_json=False)
    elif args.src == 'panther':
        run_matreex_panther(
            ids, out_path, taxon2description={}, taxon2branch_color={}, taxon2matrix_color={},
            ref_taxon=args.root_taxon.capitalize(),
            id2gene_name={}, name=name, max_gene_nr=1000000, exp_json=False, LDO=True, disable_duplicates=False)

    elif args.src == 'json':
        pass





"""
    Matreex

    This file is part of Matreex.

    Matreex is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Matreex is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Matreex. If not, see <http://www.gnu.org/licenses/>.
"""
from datetime import date

__packagename__ = "matreex"
__version__ = "0.0.1"
__copyright__ = "(C) 2022-{:d} Victor Rossier and Clement Train".format(
    date.today().year
)


"""
    Matreex

    This file is part of Matreex.

    Matreex is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Matreex is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Matreex. If not, see <http://www.gnu.org/licenses/>.
"""
from setuptools import setup, find_packages

name = 'matreex'
__version__ = None
with open('{:s}/__init__.py'.format(name), 'rt') as fp:
    for line in fp:
        if line.startswith('__version__'):
            exec(line.rstrip())

requirements = ['biopython', 'ete3', 'omadb', 'requests', 'pyham']

desc = 'Matreex: compact and interactive visualisation of large gene families using hierarchical phylogenetic profiles'

setup(
    name=name,
    version=__version__,
    author='Victor Rossier and Clement Train',
    email='victorrossier@hotmail.com',
    url='',
    description=desc,
    packages=find_packages(),
    install_requires=requirements,
    python_requires=">=3.6",
    license='LGPLv3',
    scripts=['bin/matreex'])
